# Welcome to Changemaker Lite



A streamlined, self-hosted platform for documentation and development.

## Quick Start

Get up and running in minutes:

```bash
# Clone the repository
git clone https://gitea.bnkhome.org/admin/changemaker.lite.git
cd changemaker.lite

# Configure environment
./config.sh

# Start all services
docker compose up -d
```

## Contributing to This Platform

This Changemaker Lite setup is actively used by the Alberta Democracy Taskforce and welcomes contributions from the community. Whether you want to improve the platform itself or use it for your own organization's needs, we'd love your input.

**Get involved:**
- Report issues or suggest improvements
- Contribute code enhancements 
- Share how you've adapted it for your needs
- Help make collaborative documentation easier for everyone

See our [contributing guide](../contributing/index.md) to get started, or dive directly into the [repository](https://git.albertademocracytaskforce.org/admin/ab.dem.tf.changemaker.git).

## Services

Changemaker Lite includes these essential services:

- **[Homepage](services/homepage.md)** (Port 3010) - Service dashboard and monitoring
- **[Code Server](services/code-server.md)** (Port 8888) - VS Code in your browser
- **[MkDocs](services/mkdocs.md)** (Port 4000) - Documentation with live preview  
- **[Static Server](services/static-server.md)** (Port 4001) - Built site hosting
- **[Listmonk](services/listmonk.md)** (Port 9000) - Newsletter management
- **[PostgreSQL](services/postgresql.md)** (Port 5432) - Database backend
- **[n8n](services/n8n.md)** (Port 5678) - Workflow automation
- **[NocoDB](services/nocodb.md)** (Port 8090) - No-code database platform

## Getting Started

1. **Documentation**: Start writing in [Code Server](http://localhost:8888)
2. **Preview**: See live changes at [MkDocs](http://localhost:4000)
3. **Production**: View built site at [Static Server](http://localhost:4001)
4. **Email**: Set up campaigns with [Listmonk](http://localhost:9000)
5. **Automation**: Create workflows in [n8n](http://localhost:5678)

## Project Structure

```
changemaker.lite/
├── docker-compose.yml    # Service definitions
├── config.sh            # Setup script
├── mkdocs/              # Documentation source
│   ├── docs/            # Markdown files
│   └── mkdocs.yml       # Configuration
├── configs/             # Service configurations
└── assets/              # Shared assets
```

## Learn More

- [Services Overview](services/index.md) - Detailed service documentation
- [Blog](../blog/index.md) - Updates and tutorials
- [Git Repository](https://git.albertademocracytaskforce.org/admin/ab.dem.tf.changemaker.git) - Source code and issues
- [Contributing Guide](../contributing/index.md) - How to get involved
