# Make Your First Edit

Ready to make your first contribution? This guide will walk you through editing a file directly in your web browser - no special software needed!

## What You'll Do

We'll make a simple change to practice the process. Don't worry about breaking anything - there are safeguards in place.

## Step 1: Choose a File to Edit

For your first edit, let's improve a page that already exists:

1. Go to the project homepage on Gitea
2. Navigate to `mkdocs` → `docs`
3. Find a page you'd like to improve (maybe `faq.md` or create a small edit to any `.md` file)

## Step 2: Open the Editor

1. Click on the file you want to edit
2. Look for the **pencil icon** (✏️) and click it
3. You're now in the web editor!

## Step 3: Understand Markdown

The files use "Markdown" - a simple way to format text. Here are the basics:

```markdown
# This is a big heading
## This is a smaller heading
**This text is bold**
*This text is italic*
- This is a bullet point
[This is a link](https://example.com)
```

## Step 4: Make Your Edit

Let's practice with a small change:

1. Find a paragraph you want to improve
2. Make a simple edit like:
   - Fix a typo
   - Add a sentence
   - Improve wording
3. Don't make huge changes for your first edit - keep it simple!

## Step 5: Preview Your Changes

1. Click the **"Preview"** tab to see how your changes will look
2. Switch back to **"Edit"** if you want to make more changes
3. Review your work carefully

## Step 6: Save Your Changes

At the bottom of the page, you'll see a "Commit Changes" section:

1. **Commit message**: Write a brief description of what you changed
   - Good: "Fixed typo in FAQ section"
   - Good: "Added information about voting rights"
   - Not helpful: "Updated file"

2. **Choose commit type**:
   - Select "Create a new branch for this commit and start a pull request"
   - This lets others review your changes before they go live

3. Click **"Propose Changes"**

## Step 7: Create Your Pull Request

After clicking "Propose Changes":

1. You'll see a "Pull Request" form
2. Add a title that describes your change
3. In the description, explain why you made the change
4. Click **"Create Pull Request"**

Congratulations! You've submitted your first contribution!

## What Happens Next?

- A team member will review your changes
- They might suggest improvements or ask questions
- Once approved, your changes will appear on the live website
- You'll get notified by email about any updates

## What's Next?

Now that you've made your first edit, learn more about [Git Basics](git-basics.md) to understand what just happened behind the scenes.

## Video Tutorial

*[Administrator: Add a video tutorial showing the complete process of making an edit through the web interface]*

## Troubleshooting

**Can't find the pencil icon?** Make sure you're viewing a file (not a folder) and that you're logged in.

**Preview looks wrong?** Check your Markdown syntax - missing spaces or symbols can cause formatting issues.

**Nervous about breaking something?** Don't worry! Your changes won't go live until they're reviewed and approved.
